@@ -93,7 +93,7 @@ static const char *errname = NULL;
 static shell::logproc_t errproc = (shell::logproc_t)NULL;
 static mutex_t symlock;
 static char **_orig = NULL;
-static OrderedIndex _index;
+static shell::Option *ofirst = NULL, *olast = NULL;
 static const char *_domain = NULL;
 static shell::exitproc_t _exitproc = NULL;
 static shell::numeric_t numeric_mode = shell::NO_NUMERIC;
@@ -406,8 +406,15 @@ void shell::iobuf::open(const char *path, char **argv, shell::pmode_t mode, size
 }
 
 shell::Option::Option(char shortopt, const char *longopt, const char *value, const char *help) :
-OrderedObject(&_index)
+OrderedObject()
 {
+    if(olast) {
+        olast->next = this;
+        olast = this;
+    }
+    else
+        ofirst = olast = this;
+
     while(longopt && *longopt == '-')
         ++longopt;
 
@@ -424,12 +431,12 @@ shell::Option::~Option()
 
 void shell::Option::reset(void)
 {
-    _index.reset();
+    ofirst = olast = NULL;
 }
 
 LinkedObject *shell::Option::first(void)
 {
-    return _index.begin();
+    return ofirst;
 }
 
 void shell::Option::disable(void)
@@ -1624,6 +1631,10 @@ void shell::exiting(exitproc_t handler)
         _exitproc = handler;
 }
 
+void shell::release(int exit_code)
+{
+}
+
 void shell::detach(mainproc_t entry)
 {
     const char *name = _argv0;
@@ -2172,6 +2183,63 @@ void shell::exiting(exitproc_t handler)
         _exitproc = handler;
 }
 
+void shell::release(int exit_code)
+{
+    const char *dev = "/dev/null";
+    pid_t pid;
+    int fd;
+
+    close(0);
+    close(1);
+    close(2);
+#ifdef  SIGTTOU
+    signal(SIGTTOU, SIG_IGN);
+#endif
+
+#ifdef  SIGTTIN
+    signal(SIGTTIN, SIG_IGN);
+#endif
+
+#ifdef  SIGTSTP
+    signal(SIGTSTP, SIG_IGN);
+#endif
+    pid = fork();
+    if(pid > 0)
+        exit(exit_code);
+    crit(pid == 0, "detach without process");
+
+#if defined(SIGTSTP) && defined(TIOCNOTTY)
+    crit(setpgid(0, getpid()) == 0, "detach without process group");
+    if((fd = open(_PATH_TTY, O_RDWR)) >= 0) {
+        ioctl(fd, TIOCNOTTY, NULL);
+        close(fd);
+    }
+#else
+
+#ifdef HAVE_SETPGRP
+    crit(setpgrp() == 0, "detach without process group");
+#else
+    crit(setpgid(0, getpid()) == 0, "detach without process group");
+#endif
+    signal(SIGHUP, SIG_IGN);
+    pid = fork();
+    if(pid > 0)
+        exit(0);
+    crit(pid == 0, "detach without process");
+#endif
+    if(dev && *dev) {
+        fd = open(dev, O_RDWR);
+        if(fd > 0)
+            dup2(fd, 0);
+        if(fd != 1)
+            dup2(fd, 1);
+        if(fd != 2)
+            dup2(fd, 2);
+        if(fd > 2)
+            close(fd);
+    }
+}
+
 void shell::detach(mainproc_t entry)
 {
     const char *dev = "/dev/null";
